@@ -11,15 +11,18 @@ sub lookup {
     my $table = $self->{schema}->get_table( $table_name );
     Carp::croak("No such table $table_name") unless $table;
 
-    my $cond = join ' AND', map {"$_ = ?"} keys %$where;
+    my @sorted_keys = sort keys %$where;
+
+    my $columns = _get_select_columns($table, $opt);
+    my $cond = join ' AND ', map {"$_ = ?"} @sorted_keys;
     my $sql = sprintf('SELECT %s FROM %s WHERE %s %s',
-               join(',', @{$table->{columns}}),
+               join(',', @{$columns}),
                $table_name,
                $cond,
                $opt->{for_update} ? 'FOR UPDATE' : '',
            );
 
-    my $sth = $self->_execute($sql, [values %$where]);
+    my $sth = $self->_execute($sql, [@$where{@sorted_keys}]);
     my $row = $sth->fetchrow_hashref('NAME_lc');
 
     return unless $row;
@@ -35,6 +38,27 @@ sub lookup {
         }
     );
 }
+sub _get_select_columns {
+    my ($table, $opt) = @_;
+
+    my $columns;
+    if ( $opt->{'+columns'} ) {
+        $columns = [
+            @{$table->{columns}},
+            (map { ref $_ eq 'SCALAR' ? $$_ : $_ } @{$opt->{'+columns'}})
+        ];
+    }
+    elsif ( $opt->{columns} ) {
+        $columns = [
+            map { ref $_ eq 'SCALAR' ? $$_ : $_ } @{$opt->{columns}}
+        ];
+    }
+    else {
+        $columns = $table->{columns};
+    }
+
+    return $columns;
+}
 
 1;
 __END__
